use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
API
Andy
Bessarabov
CPAN
Choroba
Constants
Cook
DROLSKY
DROLSKY's
Dave
Etheridge
GLOBREF
Grundman
Ilya
Ivan
Karen
Maddy
Martynov
Mash
Mengué
Noel
OO
Olivier
PP
Params
PayPal
Pit
Rolsky
Rolsky's
SCALARREF
Tony
Validate
ValidatePP
ValidatePos
ValidateXS
Vincent
XS
and
andyg
autarch
baz
choroba
dolmen
drolsky
ether
ilya
ivan
jmash
lib
onwards
perl
pre
runtime
tony
zhtwnpanta
